FileLockError

Enum FileLockError 

pub enum FileLockError {
    UnableToAcquireLock,
}
The FileLockError enum is a generalization when one doesn’t require the fine-grained error handling enums. One can forward FileLockError as more generic return value when a method returns a FileLock***Error. On a higher level it is again convertable to crate::Error

Variants



UnableToAcquireLock