pub enum MemoryLockError {
LockFailed,
}Expand description
The MemoryLockError enum is a generalization when one doesn’t require the fine-grained error
handling enums. One can forward MemoryLockError as more generic return value when a method
returns a MemoryLock***Error.
On a higher level it is again convertable to crate::Error.
Variants
LockFailed