Process

Struct Process 

pub struct Process { /* private fields */ }
Represent a process in a POSIX system.

Implementations

Source

impl Process

pub fn from_pid(pid: ProcessId) -> Process

Creates a process from a provided id. The process does not have to exists at the time of creation. But all other methods may fail when the process does not exist.

pub fn from_self() -> Process

Create a process object from own process.

pub fn from_parent() -> Process

Create a process object from the parents process.

pub fn is_alive(&self) -> bool

Checks if the process is still alive

pub fn id(&self) -> ProcessId

Returns the id of the process.

pub fn executable(&self) -> Result<FilePath, ProcessExecutablePathError>

Returns the executable path of the Process.

pub fn send_signal(&self, signal: Signal) -> Result<(), ProcessSendSignalError>

Sends a signal to the process.

pub fn get_priority(&self) -> Result<u8, ProcessGetSchedulerError>

Returns the priority of the process. 0 is the lowest and 255 the highest priority.

pub fn set_priority( &mut self, priority: u8, ) -> Result<(), ProcessGetSchedulerError>

Set the priority of the process. 0 is the lowest priority and 255 the highest.

pub fn get_scheduler(&self) -> Result<Scheduler, ProcessGetSchedulerError>

Returns the currently in use Scheduler by the process.

pub fn set_scheduler( &mut self, scheduler: Scheduler, ) -> Result<Scheduler, ProcessSetSchedulerError>

Sets a new Scheduler for the process and returns the formerly used Scheduler on success.