ThreadError

Enum ThreadError 

pub enum ThreadError {
    FailedToSpawn,
    NameSetupFailed,
    FailedToSignal,
    FailedToSetAffinity,
}
The ThreadError enum is a generalization when one doesn’t require the fine-grained error handling enums. One can forward ThreadError as more generic return value when a method returns a Thread***Error. On a higher level it is again convertable to crate::Error.

Variants



FailedToSpawn



NameSetupFailed



FailedToSignal



FailedToSetAffinity