ThreadGuardedStackBuilder

Struct ThreadGuardedStackBuilder 

pub struct ThreadGuardedStackBuilder { /* private fields */ }
Creates a thread with a custom sized and guarded stack. This means that a region at the end of the threads stack is defined which is later used to discover possible memory issues.

Is being created when calling stack_size or guard_size inside the ThreadBuilder.

For an example take a look at ThreadBuilders last example.

Implementations

Source

impl ThreadGuardedStackBuilder

pub fn guard_size(self, value: u64) -> Self

pub fn stack_size(self, value: u64) -> Self

pub fn spawn<'thread, T, F>(self, f: F) -> Result<Thread, ThreadSpawnError>
where T: Debug + Send + 'thread, F: FnOnce() -> T + Send + 'thread,