ThreadHandle

Struct ThreadHandle 

pub struct ThreadHandle { /* private fields */ }
A thread handle can be used from within the thread to read or modify certain settings like the name or the cpu affinity.

Example


use iceoryx2_bb_posix::thread::*;

let mut handle = ThreadHandle::from_self();
println!("I am running in a thread named {}", handle.get_name().expect(""));
println!("On the following CPU cores {:?}", handle.get_affinity().expect(""));

// only run on CPU 0
handle.set_affinity(0);

Implementations

Source

impl ThreadHandle

pub fn from_self() -> ThreadHandle

Returns a handle to the callers thread.